@@ -29,6 +29,8 @@ mod u8;
 mod bignum;
 mod dec2flt;
 mod flt2dec;
+mod ops;
+mod wrapping;
 
 mod nan;
 
